@@ -32,17 +32,11 @@ setMethod("show", "timeSeries",
         # FUNCTION:
 
         # Check records to get printed:
-        maxRmetrics <-
-            if (!is.null(max <- getRmetricsOptions("max.print")))
-                max
-            else
-                Inf
-        maxR <-
-            if (!is.null(max <- getOption("max.print") ))
-                floor(max / (NCOL(object) + NCOL(object@recordIDs)))
-            else
-                Inf
-        max <- min(c(maxRmetrics, maxR))
+        maxRmetrics <- as.numeric(getRmetricsOptions("max.print"))
+        maxR <- as.numeric(getOption("max.print"))
+        maxR <- floor(maxR / (NCOL(object) + NCOL(object@recordIDs)))
+        max <- min(na.omit(c(maxRmetrics, maxR, Inf)))
+        #-> Inf to cast case when maxRmetrics and maxR are NULL
 
         if (ptest <- ((omitted <- NROW(object) - max) > 0))
             object <- object[seq.int(max),]
@@ -53,7 +47,7 @@ setMethod("show", "timeSeries",
 
         # Series:
         cat(FinCenter, "\n", sep = "")
-        if (prod(dim(recordIDs)) & (ncol(data) == NCOL(recordIDs))) {
+        if (prod(dim(recordIDs)) & (nrow(data) == NROW(recordIDs))) {
             dataIDs <- as.matrix(recordIDs)
             colnames(dataIDs) <- paste(colnames(dataIDs), "*", sep = "")
             #-> use format(data) to have same number of digits when timeSeries
@@ -65,7 +59,7 @@ setMethod("show", "timeSeries",
 
         # print message
         if (ptest)
-            cat(gettextf("...\n [ reached getRmetricsOptions('max.print') | getOption('max.print') -- omitted %i rows ]]\n", omitted))
+            cat(gettextf("...\n [ reached getRmetricsOption('max.print') | getOption('max.print') -- omitted %i rows ]]\n", omitted))
 
         # Return Value:
         invisible(NULL) # as specified in ?show
@@ -130,20 +124,20 @@ setMethod("show", "timeSeries",
         cat(finCenter(x), "\n")
         X <- getDataPart(x)
         rownames(X) = charvec
-        print(X)
+        print(X, ...)
     } else if (style == "h") {
         stopifnot(isUnivariate(x))
         # print(as.vector(x))
         ans = as.matrix(x)[,1]
         names(ans) = charvec
-        print(ans)
+        print(ans, ...)
     } else if (style == "ts") {
         freq = c(month = 12, quarter = 4)
         start(x)
         start = unlist(atoms(start(x)))
         end = unlist(atoms(end(x)))
         ts = ts(as.vector(x), start[1:2], end[1:2], freq[by])
-        print(ts)
+        print(ts, ...)
     }
 
     # Return Value:
